#[repr(u8)]pub enum Sm1stsCmpf {
Show 64 variants
NO_EVENT = 0,
EVENT = 1,
_RESERVED_2 = 2,
_RESERVED_3 = 3,
_RESERVED_4 = 4,
_RESERVED_5 = 5,
_RESERVED_6 = 6,
_RESERVED_7 = 7,
_RESERVED_8 = 8,
_RESERVED_9 = 9,
_RESERVED_a = 10,
_RESERVED_b = 11,
_RESERVED_c = 12,
_RESERVED_d = 13,
_RESERVED_e = 14,
_RESERVED_f = 15,
_RESERVED_10 = 16,
_RESERVED_11 = 17,
_RESERVED_12 = 18,
_RESERVED_13 = 19,
_RESERVED_14 = 20,
_RESERVED_15 = 21,
_RESERVED_16 = 22,
_RESERVED_17 = 23,
_RESERVED_18 = 24,
_RESERVED_19 = 25,
_RESERVED_1a = 26,
_RESERVED_1b = 27,
_RESERVED_1c = 28,
_RESERVED_1d = 29,
_RESERVED_1e = 30,
_RESERVED_1f = 31,
_RESERVED_20 = 32,
_RESERVED_21 = 33,
_RESERVED_22 = 34,
_RESERVED_23 = 35,
_RESERVED_24 = 36,
_RESERVED_25 = 37,
_RESERVED_26 = 38,
_RESERVED_27 = 39,
_RESERVED_28 = 40,
_RESERVED_29 = 41,
_RESERVED_2a = 42,
_RESERVED_2b = 43,
_RESERVED_2c = 44,
_RESERVED_2d = 45,
_RESERVED_2e = 46,
_RESERVED_2f = 47,
_RESERVED_30 = 48,
_RESERVED_31 = 49,
_RESERVED_32 = 50,
_RESERVED_33 = 51,
_RESERVED_34 = 52,
_RESERVED_35 = 53,
_RESERVED_36 = 54,
_RESERVED_37 = 55,
_RESERVED_38 = 56,
_RESERVED_39 = 57,
_RESERVED_3a = 58,
_RESERVED_3b = 59,
_RESERVED_3c = 60,
_RESERVED_3d = 61,
_RESERVED_3e = 62,
_RESERVED_3f = 63,
}Variants
NO_EVENT = 0
No compare event has occurred for a particular VALx value.
EVENT = 1
A compare event has occurred for a particular VALx value.
_RESERVED_2 = 2
_RESERVED_3 = 3
_RESERVED_4 = 4
_RESERVED_5 = 5
_RESERVED_6 = 6
_RESERVED_7 = 7
_RESERVED_8 = 8
_RESERVED_9 = 9
_RESERVED_a = 10
_RESERVED_b = 11
_RESERVED_c = 12
_RESERVED_d = 13
_RESERVED_e = 14
_RESERVED_f = 15
_RESERVED_10 = 16
_RESERVED_11 = 17
_RESERVED_12 = 18
_RESERVED_13 = 19
_RESERVED_14 = 20
_RESERVED_15 = 21
_RESERVED_16 = 22
_RESERVED_17 = 23
_RESERVED_18 = 24
_RESERVED_19 = 25
_RESERVED_1a = 26
_RESERVED_1b = 27
_RESERVED_1c = 28
_RESERVED_1d = 29
_RESERVED_1e = 30
_RESERVED_1f = 31
_RESERVED_20 = 32
_RESERVED_21 = 33
_RESERVED_22 = 34
_RESERVED_23 = 35
_RESERVED_24 = 36
_RESERVED_25 = 37
_RESERVED_26 = 38
_RESERVED_27 = 39
_RESERVED_28 = 40
_RESERVED_29 = 41
_RESERVED_2a = 42
_RESERVED_2b = 43
_RESERVED_2c = 44
_RESERVED_2d = 45
_RESERVED_2e = 46
_RESERVED_2f = 47
_RESERVED_30 = 48
_RESERVED_31 = 49
_RESERVED_32 = 50
_RESERVED_33 = 51
_RESERVED_34 = 52
_RESERVED_35 = 53
_RESERVED_36 = 54
_RESERVED_37 = 55
_RESERVED_38 = 56
_RESERVED_39 = 57
_RESERVED_3a = 58
_RESERVED_3b = 59
_RESERVED_3c = 60
_RESERVED_3d = 61
_RESERVED_3e = 62
_RESERVED_3f = 63
Implementations
Sourceimpl Sm1stsCmpf
impl Sm1stsCmpf